# UFMA Scrapperpy

![](https://github.com/inovacampus/ufma-scapperpy/workflows/.github/workflows/pythonpackage.yml/badge.svg)

![](https://github.com/inovacampus/ufma-scapperpy/workflows/Python%20package/badge.svg)